@@ -24,7 +24,8 @@ from __future__ import print_function
 import numpy.lib.recfunctions
 import numpy as np
 
-def AppendField(dataAll,(FName,dataType)):
+def AppendField(dataAll,FN):
+    (FName,dataType)=FN
     dataCol=np.zeros((dataAll.shape[0],),dtype=dataType)
 
     dataOut=numpy.lib.recfunctions.append_fields(dataAll, FName, dataCol, usemask=False)
